==> lintian_2.28.0~bpo10+1.tar.xz: lintian-2.28.0~bpo10+1/checks/fields/format.pm <==
# fields/format -- lintian check script (rewrite) -*- perl -*-
#
# Copyright (C) 2004 Marc Brockschmidt
#
# Parts of the code were taken from the old check script, which
# was Copyright (C) 1998 Richard Braakman (also licensed under the
# GPL 2 or higher)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::fields::format;

use strict;
use warnings;
use autodie;

use Moo;

use Lintian::Tags qw(tag);

with('Lintian::Check');

our @supported_source_formats = (qr/1\.0/, qr/3\.0\s*\((quilt|native)\)/);

sub source {
    my ($self) = @_;

    my $info = $self->info;

    my $format = $info->unfolded_field('format');

    return
      unless defined $format;

    my $supported = 0;
    foreach my $f (@supported_source_formats){

        $supported = 1
          if $format =~ /^\s*$f\s*\z/;
    }

    tag 'unsupported-source-format', $format
      unless $supported;

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et

==> lintian_2.32.0~bpo10+1.tar.xz: lintian-2.32.0~bpo10+1/checks/fields/format.pm <==
# fields/format -- lintian check script (rewrite) -*- perl -*-
#
# Copyright (C) 2004 Marc Brockschmidt
#
# Parts of the code were taken from the old check script, which
# was Copyright (C) 1998 Richard Braakman (also licensed under the
# GPL 2 or higher)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::fields::format;

use strict;
use warnings;
use autodie;

use Moo;

with('Lintian::Check');

our @supported_source_formats = (qr/1\.0/, qr/3\.0\s*\((quilt|native)\)/);

sub source {
    my ($self) = @_;

    my $info = $self->info;

    my $format = $info->unfolded_field('format');

    return
      unless defined $format;

    my $supported = 0;
    foreach my $f (@supported_source_formats){

        $supported = 1
          if $format =~ /^\s*$f\s*\z/;
    }

    $self->tag('unsupported-source-format', $format) unless $supported;

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et
